@@ -9,7 +9,7 @@ use warnings;
 
 use experimental qw( signatures postderef );
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Ref::Util;
 use List::Util;
@@ -248,16 +248,49 @@ sub may ( $self, $meth, $attributes = $self->__regentry( +ITERATOR ) ) {
       : 1;
 }
 
+
+
+
+
+
+
+
+
+
+
+
 sub _namespaces {
     return 'Iterator::Flex';
 }
 
+
+
+
+
+
+
+
+
+
+
+
 sub _role_namespaces {
     return 'Iterator::Flex::Role';
 }
 
 
-# return the role name for a given method
+
+
+
+
+
+
+
+
+
+
+
+
 sub _add_roles ( $class, @roles ) {
     Role::Tiny->apply_roles_to_package( $class,
         map { $class->_load_role( $_ ) } @roles );
@@ -281,22 +314,74 @@ sub _apply_method_to_depends ( $self, $meth ) {
     }
 }
 
+
+
+
+
+
+
+
 sub is_exhausted ( $self ) {
     $self->get_state == +IterState_EXHAUSTED;
 }
 
+
+
+
+
+
+
+
+
+
+
+
 sub set_exhausted ( $self ) {
     $self->set_state( +IterState_EXHAUSTED );
 }
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub _clear_state ( $self ) {
     $self->set_state( +IterState_CLEAR );
 }
 
+
+
+
+
+
+
+
 sub is_error ( $self ) {
     $_[0]->get_state == +IterState_ERROR;
 }
 
+
+
+
+
+
+
+
+
+
+
+
 sub set_error ( $self ) {
     $self->set_state( +IterState_ERROR );
 }
@@ -332,7 +417,7 @@ Iterator::Flex::Base - Iterator object
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 METHODS
 
@@ -360,17 +445,87 @@ Returns the subroutine which returns the next value from the iterator.
 
   $bool = $iter->may( $method );
 
-Similar to L<can|UNIVERSAL/can>, except it checks to ensure that the
-method can be called on the iterators which C<$iter> depends on.  For
-example, it's possible that C<$iter> implements a C<rewind> method,
-but that it's dependencies do not.  In that case C<can|UNIVESAL/can>
-will return true, but C<may> will return false.
+Similar to L<can|UNIVERSAL/can>, except it checks that the method can
+be called on the iterators which C<$iter> depends on.  For example,
+it's possible that C<$iter> implements a C<rewind> method, but that
+it's dependencies do not.  In that case L<can|UNIVERSAL/can> will
+return true, but C<may> will return false.
+
+=head2 _namespaces
+
+ @namespaces = $class->_namespaces;
+
+Returns a list of namespaces to search for classes.  When called on the base class,
+this returns
+
+ Iterator::Flex
+
+=head2 _role_namespaces
+
+ @namespaces = $class->_role_namespaces;
+
+Returns a list of namespaces to search for roles.  When called on the base class,
+returns
+
+ Iterator::Flex::Role
+
+=head2 _add_roles
+
+  $class->_add_roles( @roles );
+
+Add roles to the class. If the name begins with a C<+>, it is assumed
+to be a fully qualified name, otherwise it is searched for in the
+namespaces returned by the C<<
+L<_role_namespaces|Iterator::Flex::Base/_role_namespaces> >> class
+method.
+
+=head2 is_exhausted
+
+An object method which returns true if the iterator is in the
+L<exhausted state|Iterator::Flex::Manual::Overview/Exhausted State>
+
+=head2 set_exhausted
+
+I<Internal method.>
+
+An object method which sets the iterator state status to
+L<exhausted|Iterator::Flex::Manual::Overview/Exhausted State>.
+
+It does I<not> signal exhaustion.
+
+=head2 is_error
+
+An object method which returns true if the iterator is in the
+L<error state|Iterator::Flex::Manual::Overview/Error State>
+
+=head2 set_error
+
+I<Internal method.>
+
+An object method which sets the iterator state status to
+L<error|Iterator::Flex::Manual::Overview/Error State>.
+
+It does I<not> signal error.
+
+=begin internal
+
+=method _clear_state
+
+I<Internal method.>
+
+An  object method which clears the state status.  After
+this call, this will hold:
+
+  $iter->is_error => false
+  $iter->is_exhausted => false
+
+=end internal
 
 =head1 SUPPORT
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex
+Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex>
 
 =head2 Source
 
