@@ -8,7 +8,7 @@ use warnings;
 
 use experimental qw( signatures declared_refs refaliasing);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Ref::Util        ();
 use Role::Tiny       ();
@@ -402,7 +402,7 @@ Iterator::Flex::Factory - Create on-the-fly Iterator::Flex classes/objects
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 CLASS METHODS
 
@@ -479,7 +479,7 @@ by the constructed iterator:
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex
+Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex>
 
 =head2 Source
 
