@@ -5,7 +5,7 @@ package Iterator::Flex::Role::Exhaustion::ImportedThrow;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Role::Tiny;
 
@@ -33,13 +33,13 @@ Iterator::Flex::Role::Exhaustion::ImportedThrow - Imported iterator throws
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SUPPORT
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex
+Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex>
 
 =head2 Source
 
