@@ -1,11 +1,11 @@
 package Iterator::Flex::Role::Exhaustion::Return;
 
-# ABSTRACT: signal exhaustion by setting exhausted flag;
+# ABSTRACT: signal exhaustion by returning a sentinel value.
 
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Scalar::Util();
 use Iterator::Flex::Utils qw[ :default :RegistryKeys ];
@@ -61,11 +61,11 @@ __END__
 
 =head1 NAME
 
-Iterator::Flex::Role::Exhaustion::Return - signal exhaustion by setting exhausted flag;
+Iterator::Flex::Role::Exhaustion::Return - signal exhaustion by returning a sentinel value.
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 METHODS
 
@@ -79,14 +79,14 @@ returns the sentinel which the iterator will return to signal exhaustion
 
    $sentinel = $iterator->signal_exhaustion;
 
-Signal that the iterator is exhausted, by setting the iterators I<exhausted> flag
-and returning the iterator's sentinel value.
+Signal that the iterator is exhausted, by calling C<<
+$self->set_exhausted >> and returning the iterator's sentinel value.
 
 =head1 SUPPORT
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex
+Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex>
 
 =head2 Source
 
