@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use experimental 'signatures', 'postderef';
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Scalar::Util;
 use List::Util;
@@ -223,7 +223,7 @@ Iterator::Flex::Sequence - Numeric Sequence Iterator Class
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 METHODS
 
@@ -238,7 +238,7 @@ version 0.12
   # sequence starting at $begin, incrementing by $step, ending <= $end
   $iterator = Iterator::Flex::Sequence->new( $begin, $end, $step, ?\%pars );
 
-The optional C<%pars> hash may contain standard I<signal
+The optional C<%pars> hash may contain standard L<signal
 parameters|Iterator::Flex::Manual::Overview/Signal Parameters>.
 
 The iterator supports the following capabilities:
@@ -261,7 +261,7 @@ The iterator supports the following capabilities:
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex
+Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex>
 
 =head2 Source
 
