@@ -9,7 +9,7 @@ use warnings;
 
 use experimental 'signatures', 'postderef';
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Scalar::Util qw( refaddr );
 use Ref::Util qw( is_hashref );;
@@ -127,6 +127,10 @@ sub create_class_with_roles ( $base, @roles ) {
 
 
 
+
+
+
+
 sub parse_pars ( @args ) {
 
     my %pars = do {
@@ -223,7 +227,7 @@ Iterator::Flex::Utils - Internal utilities
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SUBROUTINES
 
@@ -231,7 +235,11 @@ version 0.12
 
   ( $mpars, $ipars, $spars ) = parse_params( \%args  );
 
-Returns the I<model>, I<interface>, and I<signal> parameters from C<%args>.
+Returns the
+L<model|Iterator::Flex::Manual::Overview/Model Parameters>
+L<interface|Iterator::Flex::Manual::Overview/Interface Parameters>
+L<signal|Iterator::Flex::Manual::Overview/Signal Parameters>
+parameters from C<%args>.
 
 =head2 check_invalid_interface_parameters
 
@@ -261,7 +269,7 @@ Returns valid signal parameters;
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex
+Please report any bugs or feature requests to bug-iterator-flex@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Iterator-Flex>
 
 =head2 Source
 
